==> n3_sdk-1.3.1r03.zip: n3_sdk-1.3.1/lib/component/n3c_widget-1.0.0-min.js <==

N3C.Validator=Class.cast({Abstract:{validate:null},newInstance:function(){}});N3C.RequiredValidator=Class.cast({Extends:N3C.Validator,newInstance:function(){this.superClass();},validate:function(w){var d=w.loadValue();return(d!==null&&d!=="");}});N3C.RegExpValidator=Class.cast({Extends:N3C.Validator,_regexp:null,newInstance:function(r){this.superClass();this._regexp=new RegExp(r);},validate:function(w){var d=w.loadValue();return this._regexp.exec(w.loadValue())!=null;}});N3C.WidgetErrorMessageGenerator={getErrorMessage:null};N3C.Widget=Class.cast({Extends:N3C,Virtual:{loadValue:function(){return this.raw.value;},setValue:function(v){this.raw.value=v;}},_ems:null,_validators:null,_id:null,newInstance:function(e,req,dc){this.superClass(e);this._validators=[];if(req){this.addValidator(new N3C.RequiredValidator());}
if(dc){this.attachDesign(dc);}},addValidator:function(v){this._validators.push(v);return this;},validate:function(emg){var fc=0;this._ems=[];for(var i=0,v;v=this._validators[i];i++){if(v.validate(this)===false){this._ems.push(emg.getErrorMessage(this,v));fc++;}}
return fc===0;},getValidatorCount:function(){return this._validators.length;},getErrors:function(){return this._ems;},isEnabled:function(){return this.raw.disabled!=true;},setEnabled:function(b){this.raw.disabled=!b;}});N3C.WidgetContainer=Class.cast({Virtual:{validate:function(emg){if(Class.interfaceOf(emg,N3C.WidgetErrorMessageGenerator)){this._eps={};var fc=0;for(var id in this._widgets){var w=this._widgets[id];if(w.validate(emg)===false){this._eps[id]=w._ems;fc++;}}
return fc===0;}
else{throw new Error("Parameter must implement \"N3C.WidgetErrorMessageGenerator\" interface.");}}},_container:null,_widgets:null,_validators:null,_eps:null,newInstance:function(c){if(!(c instanceof N3C)){throw new Error("Parameter is not compoent.");}
this._container=c;this._widgets={};this._validators=[];},addValidator:function(v){this._validators.push(v);return this;},getComponent:function(){return this._container;},addWidget:function(w){if(!(w instanceof N3C.Widget)){throw new Error("Parameter is not widget.");}
this._widgets[w.getID()]=w;return this;},getWidget:function(id){return this._widgets[id];},getAllErrors:function(){return this._eps;},getWidgetError:function(w){return this._eps[w.getID()];}});N3C.Form=Class.cast({Extends:N3C,newInstance:function(id,dc){var e=document.createElement("form");e.id=id;this.superClass(e);if(dc){this.attachDesign(dc);}
this.addEventsWithName(N3C.handler(this,this.onSubmit),null,"submit");},addQueryValue:function(id,v){var q=document.createElement("hidden");q.id=id;q.value=v;this.add(new N3C(q));},submit:function(){this.raw.submit();},reset:function(){this.raw.reset();},onSubmit:function(src,p,e){if(!this.raw.action){e.preventDefault();}}});N3C.Input=Class.cast({Extends:N3C.Widget,newInstance:function(id,type,req,dc){var e=document.createElement("input");e.id=id;e.type=type;this.superClass(e,req,dc);e.addEventListener("keypress",function(e){return e.keyCode!==13;},true);},setValueChangedListener:function(l){if(Class.interfaceOf(l,N3C.WidgetValueChangedListener)){var _this=this;this.raw.addEventListener("change",function(e){l.widgetValueChanged.call(l,_this);},true);}
else{throw new Error("Parameter must implement \"N3C.WidgetValueChangedListener\" interface.");}},setKeyEvents:function(o){this.raw.addEventListener("keydown",function(e){var f=o[e.keyCode];if(f){f.call();}},false);}});N3C.WidgetValueChangedListener={widgetValueChanged:null};N3C.TextField=Class.cast({Extends:N3C.Input,newInstance:function(id,req,dc,ph,size,max){this.superClass(id,"text",req,dc);if(ph){this.setAttribute("placeholder",ph);}
if(size>0){this.raw.size=size;}
if(max){this.setAttribute("maxlength",max);}}});N3C.PasswordTextField=Class.cast({Extends:N3C.Input,newInstance:function(id,dc,size,max){this.superClass(id,"password",true,dc);if(size){this.setAttribute("size",size);}
if(max){this.setAttribute("maxlength",max);}}});N3C.TypedInput=Class.cast({Extends:N3C.Input,newInstance:function(id,type,dc){this.superClass(id,type,true,dc);}});N3C.Radio=Class.cast({Extends:N3C.Input,newInstance:function(id,gn,c,dc){this.superClass(id,"radio",false,dc);this.setAttribute("name",gn);this.raw.checked=c||false;},isChecked:function(){return this.raw.checked;}});N3C.CheckBox=Class.cast({Extends:N3C.Input,newInstance:function(id,c,dc){this.superClass(id,"checkbox",false,dc);this.raw.checked=c||false;},isChecked:function(){return this.raw.checked;}});N3C.Select=Class.cast({Extends:N3C.Widget,newInstance:function(id,req,m,sz,dc){var s=document.createElement("select");s.id=id;if(m){s.multiple="multiple";}
if(sz){s.size=sz;}
this.superClass(s,req,dc);},loadValue:function(){var v=[];var options=this.raw.options;for(var i=0,o;o=options[i];i++){if(o.selected&&!o.disabled){if(o.value){v.push(o.value);}}}
return v.length>0?v:null;},getSelectedIndex:function(){return this.raw.selectedIndex;},setSelectedIndex:function(i){return this.raw.selectedIndex=i;},getOptionCount:function(){return this.raw.length;},getTextAt:function(i){return this.raw.options[i].text;},getValueAt:function(i){return this.raw.options[i].value;},isSelectedAt:function(i){return this.raw.options[i].selected;},setTextAt:function(i,t){this.raw.options[i].text=t;return this;},addOption:function(t,v,s,d){var o=new Option(t,v,s,s);if(d){o.disabled="disabled";}
this.raw.options.add(o);return this;}});N3C.TextArea=Class.cast({Extends:N3C.Widget,newInstance:function(id,req,dc,ph,rows,cols){var e=document.createElement("textarea");e.id=id;if(rows){e.rows=rows;}
if(cols){e.cols=cols;}
this.superClass(e,req,dc);if(ph){this.setAttribute("placeholder",ph);}}});N3C.Gauge=Class.cast({Extends:N3C.Input,newInstance:function(id,dc,min,max,def){this.superClass(id,"range",false,dc);var e=this.raw;e.min=min||0;e.max=max||1;e.value=def||0;},setRange:function(min,max){var e=this.raw;e.min=min;e.max=max;}});

==> n3_sdk-1.3.3r03.zip: n3_sdk-1.3.3/lib/component/n3c_widget-1.0.0-min.js <==

N3C.Validator=Class.cast({Abstract:{validate:null},newInstance:function(){}});N3C.RequiredValidator=Class.cast({Extends:N3C.Validator,newInstance:function(){this.superClass();},validate:function(w){var d=w.loadValue();return(d!==null&&d!=="");}});N3C.RegExpValidator=Class.cast({Extends:N3C.Validator,_regexp:null,newInstance:function(r){this.superClass();this._regexp=new RegExp(r);},validate:function(w){var d=w.loadValue();return this._regexp.exec(w.loadValue())!=null;}});N3C.Widget=Class.cast({Extends:N3C,Const:{ErrorMessageGenerator:{getErrorMessage:null}},Virtual:{loadValue:function(){return this.raw.value;},setValue:function(v){this.raw.value=v;}},_ems:null,_validators:null,_id:null,newInstance:function(e,req,dc){this.superClass(e);this._validators=[];if(req){this.addValidator(new N3C.RequiredValidator());}
if(dc){this.attachDesign(dc);}},addValidator:function(v){this._validators.push(v);return this;},validate:function(emg){var fc=0;this._ems=[];for(var i=0,v;v=this._validators[i];i++){if(v.validate(this)===false){this._ems.push(emg.getErrorMessage(this,v));fc++;}}
return fc===0;},getValidatorCount:function(){return this._validators.length;},getErrors:function(){return this._ems;},isEnabled:function(){return this.raw.disabled!=true;},setEnabled:function(b){this.raw.disabled=!b;}});N3C.WidgetContainer=Class.cast({Virtual:{validate:function(emg){if(Class.interfaceOf(emg,N3C.Widget.ErrorMessageGenerator)){this._eps={};var fc=0;for(var id in this._widgets){var w=this._widgets[id];if(w.validate(emg)===false){this._eps[id]=w._ems;fc++;}}
return fc===0;}
else{throw new Error("Parameter must implement \"N3C.Widget.ErrorMessageGenerator\" interface.");}}},_container:null,_widgets:null,_validators:null,_eps:null,newInstance:function(c){if(!(c instanceof N3C)){throw new Error("Parameter is not compoent.");}
this._container=c;this._widgets={};this._validators=[];},addValidator:function(v){this._validators.push(v);return this;},getComponent:function(){return this._container;},addWidget:function(w){if(!(w instanceof N3C.Widget)){throw new Error("Parameter is not widget.");}
this._widgets[w.getID()]=w;return this;},getWidget:function(id){return this._widgets[id];},getAllErrors:function(){return this._eps;},getWidgetError:function(w){return this._eps[w.getID()];}});N3C.Form=Class.cast({Extends:N3C,newInstance:function(id,dc){var e=document.createElement("form");e.id=id;this.superClass(e);if(dc){this.attachDesign(dc);}
this.addEventsWithName(N3C.handler(this,this.onSubmit),null,"submit");},addQueryValue:function(id,v){var q=document.createElement("hidden");q.id=id;q.value=v;this.add(new N3C(q));},submit:function(){this.raw.submit();},reset:function(){this.raw.reset();},onSubmit:function(src,p,e){if(!this.raw.action){e.preventDefault();}}});N3C.Input=Class.cast({Extends:N3C.Widget,newInstance:function(id,type,req,dc){var e=document.createElement("input");e.id=id;e.type=type;this.superClass(e,req,dc);e.addEventListener("keypress",function(e){return e.keyCode!==13;},true);},setValueChangedListener:function(l){if(Class.interfaceOf(l,N3C.WidgetValueChangedListener)){var _this=this;this.raw.addEventListener("change",function(e){l.widgetValueChanged.call(l,_this);},true);}
else{throw new Error("Parameter must implement \"N3C.WidgetValueChangedListener\" interface.");}},Virtual:{setKeyEvents:function(o){this.raw.addEventListener("keydown",function(e){var f=o[e.keyCode];if(f){f.call();}},false);}}});N3C.WidgetValueChangedListener={widgetValueChanged:null};N3C.TextField=Class.cast({Extends:N3C.Input,newInstance:function(id,req,dc,ph,size,max){this.superClass(id,"text",req,dc);if(ph){this.setAttribute("placeholder",ph);}
if(size>0){this.raw.size=size;}
if(max){this.setAttribute("maxlength",max);}}});N3C.PasswordTextField=Class.cast({Extends:N3C.Input,newInstance:function(id,dc,size,max){this.superClass(id,"password",true,dc);if(size){this.setAttribute("size",size);}
if(max){this.setAttribute("maxlength",max);}}});N3C.TypedInput=Class.cast({Extends:N3C.Input,newInstance:function(id,type,dc){this.superClass(id,type,true,dc);}});N3C.Radio=Class.cast({Extends:N3C.Input,newInstance:function(id,gn,c,dc){this.superClass(id,"radio",false,dc);this.setAttribute("name",gn);this.raw.checked=c||false;},isChecked:function(){return this.raw.checked;}});N3C.CheckBox=Class.cast({Extends:N3C.Input,newInstance:function(id,c,dc){this.superClass(id,"checkbox",false,dc);this.raw.checked=c||false;},isChecked:function(){return this.raw.checked;}});N3C.Select=Class.cast({Extends:N3C.Widget,newInstance:function(id,req,m,sz,dc){var s=document.createElement("select");s.id=id;if(m){s.multiple="multiple";}
if(sz){s.size=sz;}
this.superClass(s,req,dc);},loadValue:function(){var v=[];var options=this.raw.options;for(var i=0,o;o=options[i];i++){if(o.selected&&!o.disabled){if(o.value){v.push(o.value);}}}
return v.length>0?v:null;},getSelectedIndex:function(){return this.raw.selectedIndex;},setSelectedIndex:function(i){return this.raw.selectedIndex=i;},getOptionCount:function(){return this.raw.length;},getTextAt:function(i){return this.raw.options[i].text;},getValueAt:function(i){return this.raw.options[i].value;},isSelectedAt:function(i){return this.raw.options[i].selected;},setTextAt:function(i,t){this.raw.options[i].text=t;return this;},addOption:function(t,v,s,d){var o=new Option(t,v,s,s);if(d){o.disabled="disabled";}
this.raw.options.add(o);return this;}});N3C.TextArea=Class.cast({Extends:N3C.Widget,newInstance:function(id,req,dc,ph,rows,cols){var e=document.createElement("textarea");e.id=id;if(rows){e.rows=rows;}
if(cols){e.cols=cols;}
this.superClass(e,req,dc);if(ph){this.setAttribute("placeholder",ph);}}});N3C.Gauge=Class.cast({Extends:N3C.Input,newInstance:function(id,dc,min,max,def){this.superClass(id,"range",false,dc);var e=this.raw;e.min=min||0;e.max=max||1;e.value=def||0;},setRange:function(min,max){var e=this.raw;e.min=min;e.max=max;}});
